# -*- coding: utf-8 -*-
#
# 計算結果の解析の時のいろいろな計算を仮にするスクリプト
# gphys_method に加えるほどではない計算を入れる
#  例えば絵をかくところ一行だけ入れるとか
# 履歴
# 2015/08/07 作成
#
# 2015/10/27 diff, select_gphys, temp_to_pottemp, make_exner を追加
# 2015/11/18 surfn2を作成
# 2015/12/09 diff, select_gphys に surfvelvect を追加
$LOAD_PATH.push(Dir.pwd)
require './gphys_const'
require 'numru/ggraph'
require './my_utils'
include NumRu
include GGraph

def dda_make(sens, eta)
  # DDAF_d をsens と eta から計算する
  dda = DDAEfficiencyFactor * sens * eta
  return dda
end
def diff_temp_surftemp(dir,ts,te,lat,lon)
  # 地表面温度と一層上の温度の差を取る
  dir = add_slash(dir)
  st =GPhys::IO.open(dir+'SurfTemp.nc','SurfTemp') 
  temp = GPhys::IO.open(dir+'Temp.nc','Temp')
  diff = - temp.cut("time"=>ts..te,"lat"=>lat,"lon"=>lon)[0,false] + st.cut("time"=>ts..te,"lat"=>lat,"lon"=>lon)
  diff.rename("-(Temp - SurfTemp)")
  return diff
end
def ggraph_line_difftemp(temp, temp2)
  # 折れ線をかく
  GGraph.line(temp,true, 'index'=>21, 'type'=>1, 'max'=> vmax, 'min'=> vmin, 'annotate'=>false, 'legend'=>'flat')
  GGraph.line(temp2,false, 'index'=>41, 'type'=>1, 'max'=> vmax, 'min'=> vmin, 'annotate'=>false, 'legend'=>'zonal mean')
end

def ggraph_line_lt_input(gphys, gphys2, ts, te, lat, lon,vmax,vmin)
  # 折れ線を書く2
  GGraph.line(gphys.cut("time"=>ts..te,"lat"=>lat, "lon"=>lon),true, 'index'=>21, 'type'=>1, 'max'=> vmax, 'min'=> vmin, 'annotate'=>false, 'legend'=>'flat')
  GGraph.line(gphys2.cut("time"=>ts..te,"lat"=>lat, "lon"=>lon),false, 'index'=>41, 'type'=>1, 'max'=> vmax, 'min'=> vmin, 'annotate'=>false, 'legend'=>'zonal mean')
end

def diff(vname)
  # 変数を実際にある変数に変えてスイッチを配列で返す
  if vname == 'diff_press'
    tmp_vname = 'Press_top'
    switch = 'diff_press'
  elsif vname == 'diff_temp'
    tmp_vname = 'Temp'
    switch = 'diff_temp'
  elsif vname == 'diff_pottemp'
    tmp_vname = 'PotTemp'
    switch = 'diff_pottemp'
  elsif vname == 'pottemp_0'
    tmp_vname = 'PotTemp'
    switch = 'pottemp_0'
  elsif vname == 'pottemp_1'
    tmp_vname = 'PotTemp'
    switch = 'pottemp_1'
  elsif vname == 'pottemp_2'
    tmp_vname = 'PotTemp'
    switch = 'pottemp_2'
  elsif vname == 'exner_1'
    tmp_vname = 'Ps'
    switch = 'exner_1'
  elsif vname == 'exner_0'
    tmp_vname = 'Ps'
    switch = 'exner_0'
  elsif vname == 'exner_0_inv'
    tmp_vname = 'Ps'
    switch = 'exner_0_inv'
  elsif vname == 'SurfVelAbs'
    tmp_vname = 'BetaW'
    switch = 'surfvel'
  elsif vname == 'SensB_cp'
    tmp_vname = 'SensB'
    switch = 'sensb-cp'
  elsif vname == 'rho'
    tmp_vname = 'Ps'
    switch = 'rho'
  elsif vname == 'diff_pottemp_plus_rho'
    tmp_vname = 'PotTemp'
    switch = 'diff_pottemp_plus_rho'
  elsif vname == 'total'
    tmp_vname = 'PotTemp'
    switch = 'total'
  elsif vname == 'OMG'
    tmp_vname = 'OMG'
    switch = 'omg'
  elsif vname == 'U'
    tmp_vname = 'U'
    switch = 'u'
  elsif vname == 'V'
    tmp_vname = 'V'
    switch = 'v'
  elsif vname == 'surfn2'
    tmp_vname = 'SurfTemp'
    switch = 'surfn2'
  elsif vname == 'SurfVel'
    tmp_vname = 'U'
    switch = 'surfvelvect'
    tmp_vname2 = 'V'
  else
    tmp_vname = vname
    switch = nil
  end

  if switch == 'surfvelvect'
    return tmp_vname, switch, tmp_vname2
  else
    return tmp_vname, switch
  end
end

def select_gphys(gphys,dir,vname, lat=nil, begin_time=nil, end_time = nil, switch = nil, sp_file = 'sp_for_Mars_T021_MGS.nc')
  # gphys をいろいろと書き換える

  if switch
    case switch
    when 'diff_temp' then
      gphys2 = GPhys::IO.open(dir + '/SurfTemp.nc', 'SurfTemp')
      if begin_time
        if end_time
          gphys2 = gphys2.cut("time"=>begin_time..end_time)
        else
          gphys2 = gphys2.cut("time"=>begin_time)
        end
      end
      if lat 
        gphys2 = gphys2.cut("lat"=>lat)
      end
      tmp_gphys = gphys2 - gphys[false,0,true] 
      tmp_gphys.rename('- (Temp - SurfTemp)')
      tmp_gphys.long_name = 'diffrence of Surftemp and Temp'
    when 'diff_press' then
      gphys2 = GPhys::IO.open(dir + '/Ps.nc', 'Ps')
      if begin_time
        if end_time
          gphys2 = gphys2.cut("time"=>begin_time..end_time)
        else
          gphys2 = gphys2.cut("time"=>begin_time)
        end
      end
      if lat 
        gphys2 = gphys2.cut("lat"=>lat)
      end
      tmp_gphys = gphys2 - gphys[false,0,true] 
      tmp_gphys.rename('- (Press_top - Ps)')
      tmp_gphys.long_name = 'diffrence of Ps and Press_top'
    when 'diff_pottemp' then
      temp = GPhys::IO.open(dir + '/SurfTemp.nc', 'SurfTemp')
      sigm = GPhys::IO.open(dir + '/SurfTemp.nc','sigm')
      #temp1 = GPhys::IO.open(dir + '/Temp.nc', 'Temp')
      #sig = GPhys::IO.open(dir + '/Temp.nc', 'sig')
      gphys2 = temp_to_pottemp(dir,temp,sigm[0])
      #      gphys3 = temp_to_pottemp(dir,temp1[false,0,true],sig[0])
      if begin_time
        if end_time
          gphys2 = gphys2.cut("time"=>begin_time..end_time)
        else
          gphys2 = gphys2.cut("time"=>begin_time)
        end
      end
      if lat 
        gphys2 = gphys2.cut("lat"=>lat)
      end
      tmp_gphys = gphys2 - gphys[false,0,true] 
      #tmp_gphys = gphys2 - gphys3.cut("time"=>begin_time..end_time)
      tmp_gphys.rename('- (PotTemp - SurfPotTemp)')
      tmp_gphys.long_name = 'diffrence of SurfPottemp and PotTemp'
    when 'pottemp_0' then
      temp = GPhys::IO.open(dir + '/SurfTemp.nc', 'SurfTemp')
      sigm = GPhys::IO.open(dir + '/SurfTemp.nc','sigm')
      tmp_gphys = temp_to_pottemp(dir,temp,sigm[0])
      tmp_gphys.rename('SurfPotTemp')
      tmp_gphys.long_name = 'Pottemp at surface'
    when 'pottemp_1' then
      temp = GPhys::IO.open(dir + '/Temp.nc', 'Temp')
      sig = GPhys::IO.open(dir + '/Temp.nc','sig')
      tmp_gphys = temp_to_pottemp(dir,temp[false,0,true],sig[0])
      tmp_gphys.rename('PotTemp')
      tmp_gphys.long_name = 'Pottemp at lowest layer'
      #tmp_gphys = gphys[false,0,true]
    when 'pottemp_2' then
      temp = GPhys::IO.open(dir + '/Temp.nc', 'Temp')
      sig = GPhys::IO.open(dir + '/Temp.nc','sig')
      tmp_gphys = temp_to_pottemp(dir,temp[false,0,true],sig[1])
      tmp_gphys.rename('PotTemp')
      tmp_gphys.long_name = 'Pottemp at 2 layer'
    when 'exner_0' then
      sigm = GPhys::IO.open(dir + '/Ps.nc','sigm')
      tmp_gphys = make_exner(gphys, sigm[0])
      tmp_gphys.rename('Exner')
      tmp_gphys.long_name = 'Exner at surface'
    when 'exner_1' then
      sig = GPhys::IO.open(dir + '/Ps.nc','sig')
      tmp_gphys = make_exner(gphys, sig[0])
      tmp_gphys.rename('Exner')
      tmp_gphys.long_name = 'Exner at lowest layer'
    when 'surfvel' then
      u = GPhys::IO.open(dir + '/U.nc','U')
      v = GPhys::IO.open(dir + '/V.nc','V')
      tmp_gphys = (gphys.cut("time"=>begin_time..end_time)**2 + u.cut("time"=>begin_time..end_time)[false,0,true]**2 + v.cut("time"=>begin_time..end_time)[false,0,true]**2).sqrt
      tmp_gphys.rename('SurfVelAbs')
      tmp_gphys.long_name = 'absolute velocity at surface'
    when 'exner_0_inv' then
      sigm = GPhys::IO.open(dir + '/Ps.nc','sigm')
      tmp_gphys = (make_inv_exner(gphys, sigm[0]))
      tmp_gphys.rename('Inverce Exner')
      tmp_gphys.long_name = 'Inverce Exner at surface'
    when 'rho' then
      temp = GPhys::IO.open(dir + '/SurfTemp.nc','SurfTemp')
      tmp_gphys = gphys / (GasR * temp.cut("time"=>begin_time..end_time))
      tmp_gphys.rename('Rho')
      tmp_gphys.long_name = 'Rho at surface'
    when 'diff_pottemp_plus_rho' then
      temp = GPhys::IO.open(dir + '/SurfTemp.nc', 'SurfTemp')
      sigm = GPhys::IO.open(dir + '/SurfTemp.nc','sigm')
      gphys2 = temp_to_pottemp(dir,temp,sigm[0])
      if begin_time
        if end_time
          gphys2 = gphys2.cut("time"=>begin_time..end_time)
        else
          gphys2 = gphys2.cut("time"=>begin_time)
        end
      end
      if lat 
        gphys2 = gphys2.cut("lat"=>lat)
      end
      tmp_gphys = gphys2 - gphys[false,0,true]
      #tmp_gphys = gphys2 - gphys3.cut("time"=>begin_time..end_time)
      tmp_gphys.rename('- (PotTemp - SurfPotTemp) + rho')
      tmp_gphys.long_name = 'diffrence of SurfPottemp and PotTemp and rho'
    when 'omg'
      tmp_gphys = gphys[false,0,true]
    when 'u'
      tmp_gphys = gphys[false,0,true]
    when 'v'
      tmp_gphys = gphys[false,0,true]
    when 'n2'
      ps = GPhys::IO.open(dir + '/Ps.nc', 'Ps')
      sig = GPhys::IO.open(dir + '/Temp.nc', 'sig')
      sigm = GPhys::IO.open(dir + '/Temp.nc', 'sigm')
      height = GPhys::IO.open(dir + '/Height.nc', 'Height')
      surfheight = GPhys::IO.open(dir + '/' + sp_file, 'topog')
      temp = GPhys::IO.open(dir + '/Temp.nc', 'Temp')
      tmp_gphys = surfN2(ps, sigm[0], sig[0], gphys, temp.cut("time"=>begin_time..end_time)[false,0,true], height.cut("time"=>begin_time..end_time)[false,0,true], surfheight)
      tmp_gphys.rename('N^2')
      tmp_gphys.long_name = 'Stratification at surface'
    when 'surfvelvect'
      tmp_gphys = gphys[false, 0, true]
    else
      tmp_gphys = gphys
    end
  else
    tmp_gphys = gphys
  end
  return tmp_gphys
end

def temp_to_pottemp(dir,temp,sig)
  # 温度とσ座標から温位を作る
  tmp_dir = add_slash(dir)
  ps = GPhys::IO.open(tmp_dir + 'Ps.nc','Ps')
  exner = make_exner(ps,sig)
  pottemp = temp/exner
  return pottemp
end
def make_exner(ps,sig)
  # 地表面気圧とσ座標からエクスナー関数を作る
  press = ps * sig
  exner = (press / RefPress) ** (GasR/Cp)
  exner.units = '1'
  return exner
end
def make_inv_exner(ps,sig)
  # 地表面気圧とσ座標からエクスナー関数の逆数を作る
  press = ps * sig
  exner = ( RefPress / press ) ** (GasR/Cp)
  exner.units = '1'
  return exner
end
def surfN2(ps, sigm, sig, surftemp, temp, height, surfheight)
  # 地表面のブラントヴァイサラ振動数の二乗 (N^2 成層度) を求める
  surfexner = make_exner(ps, sigm)
  exner = make_exner(ps, sig)
  n2 = Grav / ( surftemp / surfexner) * ( temp / exner - surftemp / surfexner) / (height - surfheight)
  return n2
end
def tempInpol(sig, sigm)
  # 温度の鉛直方向の補正用配列z_TempInpolM, z_Tempinpol を返す 
  z_tempinpolm = NArray.float(sig.shape[0])
  z_tempinpol = NArray.float(sig.shape[0])
  #--------------計算----------------------

  z_tempinpolm[0] = 0.0
  z_tempinpol[0] = 0.0

  for k in 1..(sig.shape[0] - 2)
    z_tempinpolm[k] = (log(sigm.val[k]) - log(sig.val[k+1])) / (log(sig.val[k]) - log(sig.val[k+1]))
    z_tempinpol[k] = (log(sig.val[k]) - log(sigm.val[k])) / ( log(sig.val[k]) - log(sig.val[k+1]))
  end

  return z_tempinpolm, z_tempinpol
end
