#! /usr/bin/ruby
# -*- coding: utf-8 -*-

# 同期回転惑星計算用描画スクリプト
# == 説明
# * このスクリプトは同期回転惑星設定実験の結果の図を作成するものである.
# * このスクリプトでは, gpview, fig_heatflux-lat-dependence.rb などの
#   スクリプトが使われる.
# * 使用する場合には, fig_heatflux-lat-dependence.rb などを格納した
#   ディレクトリを指定する必要がある.
#   そのために, script_dir を適宜書き換えねばならない.
#
# == オプション
# --time_start 開始時刻
# --time_end   終了時刻
# --wsn        出力先. ps だったら --wsn=2
# --prefix     生成する画像ファイルに付ける接頭詞
#
# == USAGE
#   % fig_SyncRot.rb --time_start=731 --time_end=1095 --wsn=2 --prefix=EXPNAME_
#
# == 履歴
# * 2013-6-19 石渡正樹 作成


require "getoptlong"        # for option_parse
require "numru/ggraph"
include NumRu

script_dir = "."

## オプション解析
parser = GetoptLong.new
parser.set_options(
                   ###    global option   ###
                   ['--time_start',                      GetoptLong::REQUIRED_ARGUMENT],
                   ['--time_end',                      GetoptLong::REQUIRED_ARGUMENT],
                   ['--wsn',                      GetoptLong::REQUIRED_ARGUMENT],
                   ['--prefix',                      GetoptLong::REQUIRED_ARGUMENT]
                   )
parser.each_option do |name, arg|
    eval "$OPT_#{name.sub(/^--/, '').gsub(/-/, '_')} = '#{arg}'"  # strage option value to $OPT_val
end



wsn = ($OPT_wsn||4)
 
time_start = ($OPT_time_start||1).to_s
time_end = ($OPT_time_end||9999).to_s

timespan = time_start + ':' + time_end

# dennou-h でメモリが足りなくなる場合は, 最後の 300 日だけにする.

#p time_end.class

#value_time_start_newdata = time_end.to_i - 299
value_time_start_newdata = time_end.to_i
time_start_newdata = value_time_start_newdata.to_s


# 0 次元量の時間変化
system("#{script_dir}/fig_timeseries-heat.rb --region=all --wsn=#{wsn} && dclpsrot dcl.ps > #{$OPT_prefix}HeatFlux-all_timeseries.ps && convert #{$OPT_prefix}HeatFlux-all_timeseries.ps #{$OPT_prefix}HeatFlux-all_timeseries.png")

system("#{script_dir}/fig_timeseries-heat.rb --region=east --wsn=#{wsn} && dclpsrot dcl.ps > #{$OPT_prefix}HeatFlux-east_timeseries.ps && convert #{$OPT_prefix}HeatFlux-east_timeseries.ps #{$OPT_prefix}HeatFlux-east_timeseries.png")

system("#{script_dir}/fig_timeseries-heat.rb --region=west --wsn=#{wsn} && dclpsrot dcl.ps > #{$OPT_prefix}HeatFlux-west_timeseries.ps && convert #{$OPT_prefix}HeatFlux-west_timeseries.ps #{$OPT_prefix}HeatFlux-west_timeseries.png")


# 鉛直積算量
#system("#{script_dir}/fig_vertinteg-cloudwater.rb --time_start=#{time_start_newdata} --time_end=#{time_end}") 
#system("gpview IntegH2OLiq.nc@H2OLiq --wsn=#{wsn} --noannotate --cint=2e-10 --range=0:5e-9 && dclpsrot dcl.ps > #{$OPT_prefix}IntegH2OLiq.ps && convert #{$OPT_prefix}IntegH2OLiq.ps #{$OPT_prefix}IntegH2OLiq.png")

system("#{script_dir}/fig_vertinteg.rb --var=H2OLiq --time_start=#{time_start_newdata} --time_end=#{time_end}") 
system("gpview IntegratedH2OLiq.nc@H2OLiq --wsn=#{wsn} --noannotate --cint=0.02 --range=0:0.6 && dclpsrot dcl.ps > #{$OPT_prefix}IntegratedH2OLiq.ps && convert #{$OPT_prefix}IntegratedH2OLiq.ps #{$OPT_prefix}IntegratedH2OLiq.png")

system("#{script_dir}/fig_vertinteg.rb --var=QVap --time_start=#{time_start_newdata} --time_end=#{time_end}") 
system("gpview IntegratedQVap.nc@QVap --wsn=#{wsn} --noannotate --cint=5 --range=0:100 && dclpsrot dcl.ps > #{$OPT_prefix}IntegratedQVap.ps && convert #{$OPT_prefix}IntegratedQVap.ps #{$OPT_prefix}IntegratedQVap.png")

# p time_start_newdata

# (u,v)

system("#{script_dir}/wind-vector_geopot.rb --time_start #{time_start} --time_end #{time_end} --wsn #{wsn} --sigma 0.2 --eddy && dclpsrot dcl.ps > #{$OPT_prefix}UV-eddy_sig0.2.ps && convert #{$OPT_prefix}UV-eddy_sig0.2.ps #{$OPT_prefix}UV-eddy_sig0.2.png") 

system("#{script_dir}/wind-vector_geopot.rb --time_start #{time_start} --time_end #{time_end} --xintv 8 --yintv 5 --wsn #{wsn} --sigma 0.2 && dclpsrot dcl.ps > #{$OPT_prefix}UV_sig0.2.ps && convert #{$OPT_prefix}UV_sig0.2.ps #{$OPT_prefix}UV_sig0.2.png") 

system("#{script_dir}/wind-vector_geopot.rb --time_start #{time_start} --time_end #{time_end} --wsn #{wsn} --sigma 0.2 --eddy && dclpsrot dcl.ps > #{$OPT_prefix}UV-eddy_sig0.1.ps && convert #{$OPT_prefix}UV-eddy_sig0.1.ps #{$OPT_prefix}UV-eddy_sig0.1.png") 

system("#{script_dir}/wind-vector_geopot.rb --time_start #{time_start} --time_end #{time_end} --xintv 8 --yintv 5 --wsn #{wsn} --sigma 0.2 && dclpsrot dcl.ps > #{$OPT_prefix}UV_sig0.1.ps && convert #{$OPT_prefix}UV_sig0.1.ps #{$OPT_prefix}UV_sig0.1.png") 

# 水平速度場
# system("#{script_dir}/fig_olr-uv.rb --xfact1 0.001 --yfact1 0.001 --uxunit 1 --uyunit 1 --loncnt 0 --wsn 2 && dclpsrot dcl.ps > #{$OPT_prefix}OLR-UV.ps && convert #{$OPT_prefix}OLR-UV.ps #{$OPT_prefix}OLR-UV_from0.png")

# 水平平均鉛直分布
system("#{script_dir}/fig_Temp-vertical.rb --time_start=#{time_start} --time_end=#{time_end} --range=140:320 --lon=mean --lat=mean --wsn=#{wsn} && dclpsrot dcl.ps > #{$OPT_prefix}Temp_lonmean-latmean.ps && convert #{$OPT_prefix}Temp_lonmean-latmean.ps #{$OPT_prefix}Temp_lonmean-latmean.png")

system("#{script_dir}/fig_Temp-vertical.rb --time_start=#{time_start} --time_end=#{time_end} --range=140:320 --lon=0:180 --lat=mean --wsn=#{wsn} && dclpsrot dcl.ps > #{$OPT_prefix}Temp_daymean-latmean.ps && convert #{$OPT_prefix}Temp_daymean-latmean.ps #{$OPT_prefix}Temp_daymean-latmean.png")

system("#{script_dir}/fig_Temp-vertical.rb --time_start=#{time_start} --time_end=#{time_end} --range=140:320 --lon=180:360 --lat=mean --wsn=#{wsn} && dclpsrot dcl.ps > #{$OPT_prefix}Temp_nightmean-latmean.ps && convert #{$OPT_prefix}Temp_nightmean-latmean.ps #{$OPT_prefix}Temp_nightmean-latmean.png")

system("#{script_dir}/fig_Temp-vertical.rb --time_start=#{time_start} --time_end=#{time_end} --range=140:320 --lon=0:180 --lat=0 --wsn=#{wsn} && dclpsrot dcl.ps > #{$OPT_prefix}Temp_nightmean-lat0.ps && convert #{$OPT_prefix}Temp_nightmean-lat0.ps #{$OPT_prefix}Temp_daymean-lat0.png")

system("#{script_dir}/fig_Temp-vertical.rb --time_start=#{time_start} --time_end=#{time_end} --range=140:320 --lon=180:360 --lat=0 --wsn=#{wsn} && dclpsrot dcl.ps > #{$OPT_prefix}Temp_nightmean-lat0.ps && convert #{$OPT_prefix}Temp_nightmean-lat0.ps #{$OPT_prefix}Temp_nightmean-lat0.png")





system("#{script_dir}/fig_q-vertical.rb --time_start=#{time_start} --time_end=#{time_end} --range=1e-9:1e-2 --lon=mean --lat=mean --wsn=#{wsn} && dclpsrot dcl.ps > #{$OPT_prefix}QVap_lonmean-latmean.ps && convert #{$OPT_prefix}QVap_lonmean-latmean.ps #{$OPT_prefix}QVap_lonmean-latmean.png")

system("#{script_dir}/fig_q-vertical.rb --time_start=#{time_start} --time_end=#{time_end} --range=1e-9:1e-2 --lon=0:180 --lat=mean --wsn=#{wsn} && dclpsrot dcl.ps > #{$OPT_prefix}QVap_daymean-latmean.ps && convert #{$OPT_prefix}QVap_daymean-latmean.ps #{$OPT_prefix}QVap_daymean-latmean.png")

system("#{script_dir}/fig_q-vertical.rb --time_start=#{time_start} --time_end=#{time_end} --range=1e-9:1e-2 --lon=180:360 --lat=mean --wsn=#{wsn} && dclpsrot dcl.ps > #{$OPT_prefix}QVap_nightmean-latmean.ps && convert #{$OPT_prefix}QVap_nightmean-latmean.ps #{$OPT_prefix}QVap_nightmean-latmean.png")


# 東西平均時間変化
system("gpview QVap.nc@QVap,time=#{timespan},lat=0,sig=0.1:0 --mean lon --exch --range=1e-9:1e-5 --noannotate --wsn=#{wsn} && dclpsrot dcl.ps > #{$OPT_prefix}QVap_lonmean-lat0-timeseries.ps && convert #{$OPT_prefix}QVap_lonmean-lat0-timeseries.ps #{$OPT_prefix}QVap_lonmean-lat0-timeseries.png")

#system("gpview QVap.nc@QVap,time=0:1067:4,lat=0,sig=0.1:0 --mean lon --exch --range=1e-10:1e-5")

system("gpview U.nc@U,time=0:1067:4,lat=0,sig=0.1:0 --mean lon --exch  --nocont --wsn=#{wsn} && dclpsrot dcl.ps > #{$OPT_prefix}U_lonmean-lat0-timeseries.ps && convert #{$OPT_prefix}U_lonmean-lat0-timeseries.ps #{$OPT_prefix}U_lonmean-lat0-timeseries.png")

system("gpview Ps.nc@Ps,time=#{timespan} --mean lon --cint=1000 --range=0.9e5:1.05e5 --exch --wsn=#{wsn} --noannotate && dclpsrot dcl.ps > #{$OPT_prefix}Ps_lonmean-timeseries.ps && convert #{$OPT_prefix}Ps_lonmean-timeseries.ps #{$OPT_prefix}Ps_lonmean-timeseries.png")

system("gpview SurfTemp.nc@SurfTemp,time=#{timespan} --mean lon --range=190:310 --exch --wsn=#{wsn} --noannotate && dclpsrot dcl.ps > #{$OPT_prefix}SurfTemp_lonmean-timeseries.ps && convert #{$OPT_prefix}SurfTemp_lonmean-timeseries.ps #{$OPT_prefix}SurfTemp_lonmean-timeseries.png")

system("gpview Rain.nc@Rain,time=#{timespan} --mean lon --range=0:1e-4 --levels=1e-10,1e-9,1e-8,1e-7,1e-6,1e-5,1e-4 --nocont --exch --wsn=#{wsn} --noannotate && dclpsrot dcl.ps > #{$OPT_prefix}Rain_lonmean-timeseries.ps && convert #{$OPT_prefix}Rain_lonmean-timeseries.ps #{$OPT_prefix}Rain_lonmean-timeseries.png")

# landplanet 設定では, 
# --range=1e-15:5e-6 が良い.

system("gpview PRCP.nc@PRCP,time=#{timespan} --mean lon --range=0:1e-4 --nocont --exch --wsn=#{wsn} --noannotate && dclpsrot dcl.ps > #{$OPT_prefix}PRCP_lonmean-timeseries.ps && convert #{$OPT_prefix}PRCP_lonmean-timeseries.ps #{$OPT_prefix}PRCP_lonmean-timeseries.png")

system("gpview SurfH2OVapFluxU.nc@SurfH2OVapFluxU,time=#{timespan} --mean lon --range=0:1e-4 --nocont --exch --wsn=#{wsn} --noannotate && dclpsrot dcl.ps > #{$OPT_prefix}SurfH2OVapFluxU_lonmean-timeseries.ps && convert #{$OPT_prefix}SurfH2OVapFluxU_lonmean-timeseries.ps #{$OPT_prefix}SurfH2OVapFluxU_lonmean-timeseries.png")

system("gpview SoilMoist.nc@SoilMoist,time=#{timespan} --mean lon --range=0:1e-4 --nocont --exch --wsn=#{wsn} --noannotate && dclpsrot dcl.ps > #{$OPT_prefix}SurfH2OVapFluxU_lonmean-timeseries.ps && convert #{$OPT_prefix}SurfH2OVapFluxU_lonmean-timeseries.ps #{$OPT_prefix}SurfH2OVapFluxU_lonmean-timeseries.png")


# 球面プロット
system("#{script_dir}/fig_olr-uv.rb --xfact1 0.001 --yfact1 0.001 --uxunit 1 --uyunit 1 --loncnt 0 --range_val 120:340 --wsn 2 && dclpsrot dcl.ps > #{$OPT_prefix}OLR-UV.ps && convert #{$OPT_prefix}OLR-UV.ps #{$OPT_prefix}OLR-UV_from0.png")

system("#{script_dir}/fig_olr-uv.rb --xfact1 0.001 --yfact1 0.001 --uxunit 1 --uyunit 1 --loncnt 90 --range_val 120:340 --wsn 2 && dclpsrot dcl.ps > #{$OPT_prefix}OLR-UV.ps && convert #{$OPT_prefix}OLR-UV.ps #{$OPT_prefix}OLR-UV_from90.png")

system("#{script_dir}/fig_olr-uv.rb --xfact1 0.001 --yfact1 0.001 --uxunit 1 --uyunit 1 --loncnt 180 --range_val 120:340 --wsn 2 && dclpsrot dcl.ps > #{$OPT_prefix}OLR-UV.ps && convert #{$OPT_prefix}OLR-UV.ps #{$OPT_prefix}OLR-UV_from180.png")

system("#{script_dir}/fig_olr-uv.rb --xfact1 0.001 --yfact1 0.001 --uxunit 1 --uyunit 1 --loncnt 270 --range_val 120:340 --wsn 2 && dclpsrot dcl.ps > #{$OPT_prefix}OLR-UV.ps && convert #{$OPT_prefix}OLR-UV.ps #{$OPT_prefix}OLR-UV_from270.png")



# 土壌データ
system("gpview SoilTemp.nc@SoilTemp,time=#{timespan} --mean time --wsn=#{wsn} --noannotate && dclpsrot dcl.ps > #{$OPT_prefix}SoilTemp.ps && convert #{$OPT_prefix}SoilTemp.ps #{$OPT_prefix}SoilTemp.png")

system("gpview SoilMoist.nc@SoilMoist,time=#{timespan} --mean time --wsn=#{wsn} --noannotate && dclpsrot dcl.ps > #{$OPT_prefix}SoilMoist.ps && convert #{$OPT_prefix}SoilMoist.ps #{$OPT_prefix}SoilMoist.png")

# 2 次元データ (noshade)

system("gpview SurfTemp.nc@SurfTemp,time=#{timespan} --mean time --noshade --wsn=#{wsn} --cint=5 --range=200:320 --noannotate && dclpsrot dcl.ps > #{$OPT_prefix}SurfTemp-noshade.ps && convert #{$OPT_prefix}SurfTemp-noshade.ps #{$OPT_prefix}SurfTemp-noshade.png")

system("gpview OLRA.nc@OLRA,time=#{timespan} --mean time --wsn=#{wsn} --noannotate --cint=10 --range=140:340 --noshade && dclpsrot dcl.ps > #{$OPT_prefix}OLRA-noshade.ps && convert #{$OPT_prefix}OLRA-noshade.ps #{$OPT_prefix}OLRA-noshade.png")

# 2 次元データ

system("gpview SurfTemp.nc@SurfTemp,time=#{timespan} --mean time --range=180:330 --wsn=#{wsn} --cint=5 --noannotate && dclpsrot dcl.ps > #{$OPT_prefix}SurfTemp.ps && convert #{$OPT_prefix}SurfTemp.ps #{$OPT_prefix}SurfTemp.png")

system("gpview OLR.nc@OLR,time=#{timespan} --mean time --wsn=#{wsn} --noannotate --sint=10 --range=130:440 && dclpsrot dcl.ps > #{$OPT_prefix}OLR.ps && convert #{$OPT_prefix}OLR.ps #{$OPT_prefix}OLR.png")

system("gpview OLRA.nc@OLRA,time=#{timespan} --mean time --wsn=#{wsn} --noannotate --cint=10 --range=120:340 && dclpsrot dcl.ps > #{$OPT_prefix}OLRA.ps && convert #{$OPT_prefix}OLRA.ps #{$OPT_prefix}OLRA.png")

system("gpview Rain.nc@Rain,time=#{timespan} --mean time --range=0:1e-4 --wsn=#{wsn} --noannotate && dclpsrot dcl.ps > #{$OPT_prefix}Rain.ps && convert #{$OPT_prefix}Rain.ps #{$OPT_prefix}Rain.png")

system("gpview PRCP.nc@PRCP,time=#{timespan} --mean time --range=0:1e-3 --cint=5e-5 --wsn=#{wsn} --noannotate && dclpsrot dcl.ps > #{$OPT_prefix}PRCP.ps && convert #{$OPT_prefix}PRCP.ps #{$OPT_prefix}PRCP.png")

system("gpview SurfH2OVapFluxU.nc@SurfH2OVapFluxU,time=#{timespan} --mean time --cint=1.0e-4 --range=0:1e-3 --wsn=#{wsn} --noannotate && dclpsrot dcl.ps > #{$OPT_prefix}SurfH2OVapFluxU.ps && convert #{$OPT_prefix}SurfH2OVapFluxU.ps #{$OPT_prefix}SurfH2OVapFluxU.png")

system("gpview Evap.nc@Evap,time=#{timespan} --mean time --wsn=#{wsn} --noannotate && dclpsrot dcl.ps > #{$OPT_prefix}Evap.ps && convert #{$OPT_prefix}Evap.ps #{$OPT_prefix}Evap.png")

system("gpview EvapU.nc@EvapU,time=#{timespan} --mean time --wsn=#{wsn} --noannotate && dclpsrot dcl.ps > #{$OPT_prefix}EvapU.ps && convert #{$OPT_prefix}EvapU.ps #{$OPT_prefix}EvapU.png")

system("gpview Sens.nc@Sens,time=#{timespan} --mean time --wsn=#{wsn} --noannotate && dclpsrot dcl.ps > #{$OPT_prefix}Sens.ps && convert #{$OPT_prefix}Sens.ps #{$OPT_prefix}Sens.png")

system("gpview SensA.nc@SensA,time=#{timespan} --mean time --wsn=#{wsn} --noannotate && dclpsrot dcl.ps > #{$OPT_prefix}SensA.ps && convert #{$OPT_prefix}SensA.ps #{$OPT_prefix}SensA.png")

system("gpview OSR.nc@OSR,time=#{timespan} --mean time --wsn=#{wsn} --noannotate && dclpsrot dcl.ps > #{$OPT_prefix}OSR.ps && convert #{$OPT_prefix}OSR.ps #{$OPT_prefix}OSR.png")

system("gpview OSRA.nc@OSRA,time=#{timespan} --mean time --wsn=#{wsn} --noannotate && dclpsrot dcl.ps > #{$OPT_prefix}OSRA.ps && convert #{$OPT_prefix}OSRA.ps #{$OPT_prefix}OSRA.png")

system("gpview SSR.nc@SSR,time=#{timespan} --mean time --wsn=#{wsn} --noannotate && dclpsrot dcl.ps > #{$OPT_prefix}SSR.ps && convert #{$OPT_prefix}SSR.ps #{$OPT_prefix}SSR.png")

system("gpview SSRA.nc@SSRA,time=#{timespan} --mean time --wsn=#{wsn} --noannotate && dclpsrot dcl.ps > #{$OPT_prefix}SSRA.ps && convert #{$OPT_prefix}SSRA.ps #{$OPT_prefix}SSRA.png")

system("gpview SurfAlbedo.nc@SurfAlbedo,time=#{timespan} --mean time --wsn=#{wsn} --noannotate && dclpsrot dcl.ps > #{$OPT_prefix}SurfAlbedo.ps && convert #{$OPT_prefix}SurfAlbedo.ps #{$OPT_prefix}SurfAlbedo.png")

system("gpview Ps.nc@Ps,time=#{timespan} --mean time --cint=1000 --range=86000:105000 --wsn=#{wsn} --noannotate && dclpsrot dcl.ps > #{$OPT_prefix}Ps.ps && convert #{$OPT_prefix}Ps.ps #{$OPT_prefix}Ps.png")

system("gpview SurfSnow.nc@SurfSnow,time=#{timespan} --mean time --wsn=#{wsn} --noannotate && dclpsrot dcl.ps > #{$OPT_prefix}SurfSnow.ps && convert #{$OPT_prefix}SurfSnow.ps #{$OPT_prefix}SurfSnow.png")

system("gpview SeaIceConc.nc@SeaIceConc,time=#{timespan} --mean time --wsn=#{wsn} --noannotate && dclpsrot dcl.ps > #{$OPT_prefix}SeaIceConc.ps && convert #{$OPT_prefix}SeaIceConc.ps #{$OPT_prefix}SeaIceConc.png")

## 3 次元データ

# 温度
system("gpview Temp.nc@Temp,time=#{timespan} --mean lon,time --wsn=#{wsn} --itr=2 --noannotate --sint=10 --range=140:300 && dclpsrot dcl.ps > #{$OPT_prefix}Temp_mean0-360_itr2.ps && convert #{$OPT_prefix}Temp_mean0-360_itr2.ps #{$OPT_prefix}Temp_mean0-360_itr2.png")

system("gpview Temp.nc@Temp,lon=0:180,time=#{timespan} --mean lon,time --wsn=#{wsn} --itr=2 --noannotate --sint=10 --range=140:300 && dclpsrot dcl.ps > #{$OPT_prefix}Temp_mean0-180_itr2.ps && convert #{$OPT_prefix}Temp_mean0-180_itr2.ps #{$OPT_prefix}Temp_mean0-180_itr2.png")

system("gpview Temp.nc@Temp,lon=180:360,time=#{timespan} --mean lon,time --wsn=#{wsn} --itr=2 --noannotate --sint=10 --range=140:300 && dclpsrot dcl.ps > #{$OPT_prefix}Temp_mean180-360_itr2.ps && convert #{$OPT_prefix}Temp_mean180-360_itr2.ps #{$OPT_prefix}Temp_mean180-360_itr2.png")

system("gpview Temp.nc@Temp,sig=0.1,time=#{timespan} --mean time --wsn=#{wsn}  --noannotate --sint=10 --range=140:300 && dclpsrot dcl.ps > #{$OPT_prefix}Temp_sig0.1.ps && convert #{$OPT_prefix}Temp_sig0.1.ps #{$OPT_prefix}Temp_sig0.1.png")

system("gpview Temp.nc@Temp,sig=0.077,time=#{timespan} --mean time --wsn=#{wsn}  --noannotate --sint=10 --range=140:300 && dclpsrot dcl.ps > #{$OPT_prefix}Temp_sig0.077.ps && convert #{$OPT_prefix}Temp_sig0.077.ps #{$OPT_prefix}Temp_sig0.077.png")

system("gpview Temp.nc@Temp,lat=0,time=#{timespan} --mean time --wsn=#{wsn} --itr=2 --noannotate --sint=10 --range=140:300 && dclpsrot dcl.ps > #{$OPT_prefix}Temp_lat0_itr2.ps && convert #{$OPT_prefix}Temp_lat0_itr2.ps #{$OPT_prefix}Temp_lat0_itr2.png")


system("gpview Temp.nc@Temp,time=#{timespan} --mean lon,time --wsn=#{wsn} --itr=1 --noannotate --sint=10 --range=140:300 && dclpsrot dcl.ps > #{$OPT_prefix}Temp_mean0-360_itr1.ps && convert #{$OPT_prefix}Temp_mean0-360_itr1.ps #{$OPT_prefix}Temp_mean0-360_itr1.png")

system("gpview Temp.nc@Temp,lon=0:180,time=#{timespan} --mean lon,time --wsn=#{wsn} --itr=1 --noannotate --sint=10 --range=140:300 && dclpsrot dcl.ps > #{$OPT_prefix}Temp_mean0-180_itr1.ps && convert #{$OPT_prefix}Temp_mean0-180_itr1.ps #{$OPT_prefix}Temp_mean0-180_itr1.png")

system("gpview Temp.nc@Temp,lon=180:360,time=#{timespan} --mean lon,time --wsn=#{wsn} --itr=1 --noannotate --sint=10 --range=140:300 && dclpsrot dcl.ps > #{$OPT_prefix}Temp_mean180-360_itr1.ps && convert #{$OPT_prefix}Temp_mean180-360_itr1.ps #{$OPT_prefix}Temp_mean180-360_itr1.png")

system("gpview Temp.nc@Temp,lat=0,time=#{timespan} --mean time --wsn=#{wsn} --itr=1 --noannotate --sint=10 --range=140:300 && dclpsrot dcl.ps > #{$OPT_prefix}Temp_lat0_itr1.ps && convert #{$OPT_prefix}Temp_lat0_itr1.ps #{$OPT_prefix}Temp_lat0_itr1.png")


# 東西風
system("gpview U.nc@U,time=#{timespan} --mean lon,time --wsn=#{wsn} --itr=2 --noannotate --cint=15 --range=-70:110 && dclpsrot dcl.ps > #{$OPT_prefix}U_mean0-360_itr2.ps && convert #{$OPT_prefix}U_mean0-360_itr2.ps #{$OPT_prefix}U_mean0-360_itr2.png")

system("gpview U.nc@U,lon=0:180,time=#{timespan} --mean lon,time --wsn=#{wsn} --itr=2 --noannotate --cint=15 --range=-70:110 && dclpsrot dcl.ps > #{$OPT_prefix}U_mean0-180_itr2.ps && convert #{$OPT_prefix}U_mean0-180_itr2.ps #{$OPT_prefix}U_mean0-180_itr2.png")

system("gpview U.nc@U,lon=180:360,time=#{timespan} --mean lon,time --wsn=#{wsn} --itr=2 --noannotate --cint=15 --range=-70:110 && dclpsrot dcl.ps > #{$OPT_prefix}U_mean180-360_itr2.ps && convert #{$OPT_prefix}U_mean180-360_itr2.ps #{$OPT_prefix}U_mean180-360_itr2.png")

system("gpview U.nc@U,sig=0.1,time=#{timespan} --mean time --wsn=#{wsn}  --noannotate --cint=15 --range=-70:1100:100 && dclpsrot dcl.ps > #{$OPT_prefix}U_sig0.1.ps && convert #{$OPT_prefix}U_sig0.1.ps #{$OPT_prefix}U_sig0.1.png")

system("gpview U.nc@U,sig=0.077,time=#{timespan} --mean time --wsn=#{wsn}  --noannotate --cint=15 --range=-70:110 && dclpsrot dcl.ps > #{$OPT_prefix}U_sig0.077.ps && convert #{$OPT_prefix}U_sig0.077.ps #{$OPT_prefix}U_sig0.077.png")

system("gpview U.nc@U,lat=0,time=#{timespan} --mean time --wsn=#{wsn} --itr=2 --noannotate --cint=15 --range=-70:110 && dclpsrot dcl.ps > #{$OPT_prefix}U_lat0_itr2.ps && convert #{$OPT_prefix}U_lat0_itr2.ps #{$OPT_prefix}U_lat0_itr2.png")

system("gpview U.nc@U,time=#{timespan} --mean lon,time --wsn=#{wsn} --itr=1 --noannotate --cint=15 --range=-70:110 && dclpsrot dcl.ps > #{$OPT_prefix}U_mean0-360_itr1.ps && convert #{$OPT_prefix}U_mean0-360_itr1.ps #{$OPT_prefix}U_mean0-360_itr1.png")

system("gpview U.nc@U,lon=0:180,time=#{timespan} --mean lon,time --wsn=#{wsn} --itr=1 --noannotate --cint=15 --range=-70:110 && dclpsrot dcl.ps > #{$OPT_prefix}U_mean0-180_itr1.ps && convert #{$OPT_prefix}U_mean0-180_itr1.ps #{$OPT_prefix}U_mean0-180_itr1.png")

system("gpview U.nc@U,lon=180:360,time=#{timespan} --mean lon,time --wsn=#{wsn} --itr=1 --noannotate --cint=15 --range=-70:110 && dclpsrot dcl.ps > #{$OPT_prefix}U_mean180-360_itr1.ps && convert #{$OPT_prefix}U_mean180-360_itr1.ps #{$OPT_prefix}U_mean180-360_itr1.png")

system("gpview U.nc@U,lat=0,time=#{timespan} --mean time --wsn=#{wsn} --itr=1 --noannotate --cint=15 --range=-70:110 && dclpsrot dcl.ps > #{$OPT_prefix}U_lat0_itr1.ps && convert #{$OPT_prefix}U_lat0_itr1.ps #{$OPT_prefix}U_lat0_itr1.png")


# 南北風
system("gpview V.nc@V,time=#{timespan} --mean lon,time --wsn=#{wsn} --itr=2 --noannotate --sint=10 --range=-50:50 && dclpsrot dcl.ps > #{$OPT_prefix}V_mean0-360_itr2.ps && convert #{$OPT_prefix}V_mean0-360_itr2.ps #{$OPT_prefix}V_mean0-360_itr2.png")

system("gpview V.nc@V,lon=0:180,time=#{timespan} --mean lon,time --wsn=#{wsn} --itr=2 --noannotate --sint=10 --range=-50:50 && dclpsrot dcl.ps > #{$OPT_prefix}V_mean0-180_itr2.ps && convert #{$OPT_prefix}V_mean0-180_itr2.ps #{$OPT_prefix}V_mean0-180_itr2.png")

system("gpview V.nc@V,lon=180:360,time=#{timespan} --mean lon,time --wsn=#{wsn} --itr=2 --noannotate --sint=10 --range=-50:50 && dclpsrot dcl.ps > #{$OPT_prefix}V_mean180-360_itr2.ps && convert #{$OPT_prefix}V_mean180-360_itr2.ps #{$OPT_prefix}V_mean180-360_itr2.png")

system("gpview V.nc@V,sig=0.1,time=#{timespan} --mean time --wsn=#{wsn}  --noannotate --sint=10 --range=-50:50 && dclpsrot dcl.ps > #{$OPT_prefix}V_sig0.1.ps && convert #{$OPT_prefix}V_sig0.1.ps #{$OPT_prefix}V_sig0.1.png")

system("gpview V.nc@V,sig=0.077,time=#{timespan} --mean time --wsn=#{wsn}  --noannotate --sint=10 --range=-50:50 && dclpsrot dcl.ps > #{$OPT_prefix}V_sig0.077.ps && convert #{$OPT_prefix}V_sig0.077.ps #{$OPT_prefix}V_sig0.077.png")

system("gpview V.nc@V,time=#{timespan} --mean lon,time --wsn=#{wsn} --itr=1 --noannotate --sint=10 --range=-50:50 && dclpsrot dcl.ps > #{$OPT_prefix}V_mean0-360_itr1.ps && convert #{$OPT_prefix}V_mean0-360_itr1.ps #{$OPT_prefix}V_mean0-360_itr1.png")

system("gpview V.nc@V,lon=0:180,time=#{timespan} --mean lon,time --wsn=#{wsn} --itr=1 --noannotate --sint=10 --range=-50:50 && dclpsrot dcl.ps > #{$OPT_prefix}V_mean0-180_itr1.ps && convert #{$OPT_prefix}V_mean0-180_itr1.ps #{$OPT_prefix}V_mean0-180_itr1.png")

system("gpview V.nc@V,lon=180:360,time=#{timespan} --mean lon,time --wsn=#{wsn} --itr=1 --noannotate --sint=10 --range=-50:50 && dclpsrot dcl.ps > #{$OPT_prefix}V_mean180-360_itr1.ps && convert #{$OPT_prefix}V_mean180-360_itr1.ps #{$OPT_prefix}V_mean180-360_itr2.png")


# 鉛直風
system("gpview SigDot.nc@SigDot,time=#{timespan},sigm=1:0.0118 --mean lon,time --wsn=#{wsn} --itr=2 --noannotate --range=-1e-6:1e-6 && dclpsrot dcl.ps > #{$OPT_prefix}SigDot_mean0-360_itr2.ps && convert #{$OPT_prefix}SigDot_mean0-360_itr2.ps #{$OPT_prefix}SigDot_mean0-360_itr2.png")

system("gpview SigDot.nc@SigDot,lon=0:180,time=#{timespan},sigm=1:0.0118 --mean lon,time --wsn=#{wsn} --itr=2 --noannotate --range=-1e-6:1e-6 && dclpsrot dcl.ps > #{$OPT_prefix}SigDot_mean0-180_itr2.ps && convert #{$OPT_prefix}SigDot_mean0-180_itr2.ps #{$OPT_prefix}SigDot_mean0-180_itr2.png")

system("gpview SigDot.nc@SigDot,lon=180:360,time=#{timespan},sigm=1:0.0118 --mean lon,time --wsn=#{wsn} --itr=2 --noannotate --range=-1e-6:1e-6 && dclpsrot dcl.ps > #{$OPT_prefix}SigDot_mean180-360_itr2.ps && convert #{$OPT_prefix}SigDot_mean180-360_itr2.ps #{$OPT_prefix}SigDot_mean180-360_itr2.png")

system("gpview SigDot.nc@SigDot,sigm=0.1,time=#{timespan} --mean time --wsn=#{wsn}  --noannotate --range=-1e-6:1e-6 && dclpsrot dcl.ps > #{$OPT_prefix}SigDot_sig0.1.ps && convert #{$OPT_prefix}SigDot_sig0.1.ps #{$OPT_prefix}SigDot_sig0.1.png")

system("gpview SigDot.nc@SigDot,sigm=0.077,time=#{timespan} --mean time --wsn=#{wsn}  --noannotate --range=-1e-6:1e-6 && dclpsrot dcl.ps > #{$OPT_prefix}SigDot_sig0.077.ps && convert #{$OPT_prefix}SigDot_sig0.077.ps #{$OPT_prefix}SigDot_sig0.077.png")

system("gpview SigDot.nc@SigDot,sigm=0.5,time=#{timespan} --mean time --wsn=#{wsn}  --noannotate --range=-1e-6:1e-6 && dclpsrot dcl.ps > #{$OPT_prefix}SigDot_sig0.5.ps && convert #{$OPT_prefix}SigDot_sig0.5.ps #{$OPT_prefix}SigDot_sig0.5.png")

system("gpview SigDot.nc@SigDot,time=#{timespan},sigm=1:0.0118 --mean lon,time --wsn=#{wsn} --itr=1 --noannotate --range=-1e-6:1e-6 && dclpsrot dcl.ps > #{$OPT_prefix}SigDot_mean0-360_itr1.ps && convert #{$OPT_prefix}SigDot_mean0-360_itr1.ps #{$OPT_prefix}SigDot_mean0-360_itr1.png")

system("gpview SigDot.nc@SigDot,lon=0:180,time=#{timespan},sigm=1:0.0118 --mean lon,time --wsn=#{wsn} --itr=1 --noannotate --range=-1e-6:1e-6 && dclpsrot dcl.ps > #{$OPT_prefix}SigDot_mean0-180_itr1.ps && convert #{$OPT_prefix}SigDot_mean0-180_itr1.ps #{$OPT_prefix}SigDot_mean0-180_itr1.png")

system("gpview SigDot.nc@SigDot,lon=180:360,time=#{timespan},sigm=1:0.0118 --mean lon,time --wsn=#{wsn} --itr=1 --noannotate --range=-1e-6:1e-6 && dclpsrot dcl.ps > #{$OPT_prefix}SigDot_mean180-360_itr1.ps && convert #{$OPT_prefix}SigDot_mean180-360_itr1.ps #{$OPT_prefix}SigDot_mean180-360_itr1.png")



# 比湿
system("gpview QVap.nc@QVap,time=#{timespan} --mean lon,time --wsn=#{wsn} --itr=2 --noannotate --cint=1e-3 --range=1e-19:1e-2 & dclpsrot dcl.ps > #{$OPT_prefix}QVap_mean0-360_itr2.ps && convert #{$OPT_prefix}QVap_mean0-360_itr2.ps #{$OPT_prefix}QVap_mean0-360_itr2.png")

system("gpview QVap.nc@QVap,lon=0:180,time=#{timespan} --mean lon,time --wsn=#{wsn} --itr=2 --noannotate --cint=1e-3 --range=1e-19:1e-2 && dclpsrot dcl.ps > #{$OPT_prefix}QVap_mean0-180_itr2.ps && convert #{$OPT_prefix}QVap_mean0-180_itr2.ps #{$OPT_prefix}QVap_mean0-180_itr2.png")

system("gpview QVap.nc@QVap,lon=180:360,time=#{timespan} --mean lon,time --wsn=#{wsn} --itr=2 --noannotate --cint=1e-3 --range=1e-19:1e-2 && dclpsrot dcl.ps > #{$OPT_prefix}QVap_mean180-360_itr2.ps && convert #{$OPT_prefix}QVap_mean180-360_itr2.ps #{$OPT_prefix}QVap_mean180-360_itr2.png")

system("gpview QVap.nc@QVap,sig=0.1,time=#{timespan} --mean time --wsn=#{wsn}  --noannotate && dclpsrot dcl.ps > #{$OPT_prefix}QVap_sig0.1.ps && convert #{$OPT_prefix}QVap_sig0.1.ps #{$OPT_prefix}QVap_sig0.1.png")

system("gpview QVap.nc@QVap,sig=0.077,time=#{timespan} --mean time --wsn=#{wsn}  --noannotate && dclpsrot dcl.ps > #{$OPT_prefix}QVap_sig0.077.ps && convert #{$OPT_prefix}QVap_sig0.077.ps #{$OPT_prefix}QVap_sig0.077.png")

system("gpview QVap.nc@QVap,lat=0,time=#{timespan} --mean time --wsn=#{wsn} --itr=2 --noannotate --cint=1e-3 --range=1e-19:1e-2 && dclpsrot dcl.ps > #{$OPT_prefix}QVap_lat0_itr2.ps && convert #{$OPT_prefix}QVap_lat0_itr2.ps #{$OPT_prefix}QVap_lat0_itr2.png")


system("gpview QVap.nc@QVap,time=#{timespan} --mean lon,time --wsn=#{wsn} --itr=1 --noannotate --cint=1e-3 --range=1e-19:1e-2 && dclpsrot dcl.ps > #{$OPT_prefix}QVap_mean0-360_itr1.ps && convert #{$OPT_prefix}QVap_mean0-360_itr1.ps #{$OPT_prefix}QVap_mean0-360_itr1.png")

system("gpview QVap.nc@QVap,lon=0:180,time=#{timespan} --mean lon,time --wsn=#{wsn} --itr=1 --noannotate --cint=1e-3 --range=1e-19:1e-2 && dclpsrot dcl.ps > #{$OPT_prefix}QVap_mean0-180_itr1.ps && convert #{$OPT_prefix}QVap_mean0-180_itr1.ps #{$OPT_prefix}QVap_mean0-180_itr1.png")

system("gpview QVap.nc@QVap,lon=180:360,time=#{timespan} --mean lon,time --wsn=#{wsn} --itr=1 --noannotate --cint=1e-3 --range=1e-19:1e-2 && dclpsrot dcl.ps > #{$OPT_prefix}QVap_mean180-360_itr1.ps && convert #{$OPT_prefix}QVap_mean180-360_itr1.ps #{$OPT_prefix}QVap_mean180-360_itr1.png")

system("gpview QVap.nc@QVap,lat=0,time=#{timespan} --mean time --wsn=#{wsn} --itr=1 --noannotate --cint=1e-3 --range=1e-19:1e-2 && dclpsrot dcl.ps > #{$OPT_prefix}QVap_lat0_itr1.ps && convert #{$OPT_prefix}QVap_lat0_itr1.ps #{$OPT_prefix}QVap_lat0_itr1.png")

# 相対湿度
system("gpview RelHumid.nc@RelHumid,time=#{timespan} --mean lon,time --wsn=#{wsn} --itr=2 --noannotate --range=0:1.0 && dclpsrot dcl.ps > #{$OPT_prefix}RelHumid_mean0-360.ps && convert #{$OPT_prefix}RelHumid_mean0-360.ps #{$OPT_prefix}RelHumid_mean0-360.png") if File.exist?('RelHumid.nc')

system("gpview RelHumid.nc@RelHumid,lon=180:360,time=#{timespan} --mean lon,time --wsn=#{wsn} --itr=2 --noannotate --range=0:1.0 && dclpsrot dcl.ps > #{$OPT_prefix}RelHumid_mean180-360.ps && convert #{$OPT_prefix}RelHumid_mean180-360.ps #{$OPT_prefix}RelHumid_mean180-360.png") if File.exist?('RelHumid.nc')

system("gpview RelHumid.nc@RelHumid,lon=0:180,time=#{timespan} --mean lon,time --wsn=#{wsn} --itr=2 --noannotate --range=0:1.0 && dclpsrot dcl.ps > #{$OPT_prefix}RelHumid_mean0-180.ps && convert #{$OPT_prefix}RelHumid_mean0-180.ps #{$OPT_prefix}RelHumid_mean0-180.png") if File.exist?('RelHumid.nc')

# 雲水
system("gpview H2OLiq.nc@H2OLiq,time=#{timespan} --mean sig,time --wsn=#{wsn}  --cint=2.5e-6 --range=0:2.5e-5 --noannotate && dclpsrot dcl.ps > #{$OPT_prefix}H2OLiq_sigmean.ps && convert #{$OPT_prefix}H2OLiq_sigmean.ps #{$OPT_prefix}H2OLiq_sigmean.png")

system("gpview H2OLiq.nc@H2OLiq,time=#{timespan},lat=0 --mean time --wsn=#{wsn}  --noannotate && dclpsrot dcl.ps > #{$OPT_prefix}H2OLiq_lat0.ps && convert #{$OPT_prefix}H2OLiq_lat0.ps #{$OPT_prefix}H2OLiq_lat0.png")

system("gpview H2OLiq.nc@H2OLiq,time=#{timespan},lon=90 --mean time --wsn=#{wsn}  --noannotate && dclpsrot dcl.ps > #{$OPT_prefix}H2OLiq_lon90.ps && convert #{$OPT_prefix}H2OLiq_lon90.ps #{$OPT_prefix}H2OLiq_lon90.png")

# フラックス (緯度分布)
system("#{script_dir}/fig_heatfluxA-lat-dependence.rb --time_start=#{time_start} --time_end=#{time_end} --range=0:800 --lon=mean --wsn=#{wsn} && dclpsrot dcl.ps > #{$OPT_prefix}fluxes_lonmean.ps && convert #{$OPT_prefix}fluxes_lonmean.ps #{$OPT_prefix}fluxesA_lonmean.png")

system("#{script_dir}/fig_heatfluxA-lat-dependence.rb --time_start=#{time_start} --time_end=#{time_end} --range=0:800 --lon=0:180 --wsn=#{wsn} && dclpsrot dcl.ps > #{$OPT_prefix}fluxes_daymean.ps && convert #{$OPT_prefix}fluxes_daymean.ps #{$OPT_prefix}fluxesA_daymean.png")

system("#{script_dir}/fig_heatfluxA-lat-dependence.rb --time_start=#{time_start} --time_end=#{time_end} --range=0:800 --lon=180:360 --wsn=#{wsn} && dclpsrot dcl.ps > #{$OPT_prefix}fluxes_nightmean.ps && convert #{$OPT_prefix}fluxes_nightmean.ps #{$OPT_prefix}fluxesA_nightmean.png")

system("#{script_dir}/fig_heatflux-lat-dependence.rb --time_start=#{time_start} --time_end=#{time_end} --range=0:800 --lon=mean --wsn=#{wsn} && dclpsrot dcl.ps > #{$OPT_prefix}fluxes_lonmean.ps && convert #{$OPT_prefix}fluxes_lonmean.ps #{$OPT_prefix}fluxes_lonmean.png")

system("#{script_dir}/fig_heatflux-lat-dependence.rb --time_start=#{time_start} --time_end=#{time_end} --range=0:800 --lon=0:180 --wsn=#{wsn} && dclpsrot dcl.ps > #{$OPT_prefix}fluxes_daymean.ps && convert #{$OPT_prefix}fluxes_daymean.ps #{$OPT_prefix}fluxes_daymean.png")

system("#{script_dir}/fig_heatflux-lat-dependence.rb --time_start=#{time_start} --time_end=#{time_end} --range=0:800 --lon=180:360 --wsn=#{wsn} && dclpsrot dcl.ps > #{$OPT_prefix}fluxes_nightmean.ps && convert #{$OPT_prefix}fluxes_nightmean.ps #{$OPT_prefix}fluxes_nightmean.png")

# 熱フラックス (経度分布)
system("#{script_dir}/fig_heatfluxA-lon-dependence.rb --time_start=#{time_start} --time_end=#{time_end} --range=0:800 --lat=mean --wsn=#{wsn} && dclpsrot dcl.ps > #{$OPT_prefix}fluxes_latmean.ps && convert #{$OPT_prefix}fluxes_latmean.ps #{$OPT_prefix}fluxesA_latmean.png")

system("#{script_dir}/fig_heatfluxA-lon-dependence.rb --time_start=#{time_start} --time_end=#{time_end} --range=0:800 --lat=0 --wsn=#{wsn} && dclpsrot dcl.ps > #{$OPT_prefix}fluxes_lat0.ps && convert #{$OPT_prefix}fluxes_lat0.ps #{$OPT_prefix}fluxesA_lat0.png")

system("#{script_dir}/fig_heatflux-lon-dependence.rb --time_start=#{time_start} --time_end=#{time_end} --range=0:800 --lat=mean --wsn=#{wsn} && dclpsrot dcl.ps > #{$OPT_prefix}fluxes_latmean.ps && convert #{$OPT_prefix}fluxes_latmean.ps #{$OPT_prefix}fluxes_latmean.png")

system("#{script_dir}/fig_heatflux-lon-dependence.rb --time_start=#{time_start} --time_end=#{time_end} --range=0:800 --lat=0 --wsn=#{wsn} && dclpsrot dcl.ps > #{$OPT_prefix}fluxes_lat0.ps && convert #{$OPT_prefix}fluxes_lat0.ps #{$OPT_prefix}fluxes_lat0.png")


#-85.76059, -80.26878: 260K
#-74.74454, -69.21297, -63.67863, -58.14296 : 300K
#    -52.60653, -47.06964, -41.53246, -35.99508, -30.45755: 350K
# -24.91993,
#    -19.38223, -13.84448, -8.306703, -2.768903: 400K
# 2.768903, 8.306703, 13.84448,
#    19.38223, 24.91993: 450K
#    30.45755, 35.99508, 41.53246, 47.06964, 52.60653: 500K
#    58.14296, 63.67863, 69.21297, 74.74454, 80.26878: 550K 85.76059



# 質量流線関数
if File.exist?($OPT_prefix + 'StreamFunc0-360.png') then
  puts("MESSAGE: file exists. process skipped.")
else
  system("#{script_dir}/mass_stream_func.rb V.nc V Ps.nc Ps --time_start=#{time_start} --time_end=#{time_end} --lon_start=0 --lon_end=360 --wsn=#{wsn} && dclpsrot dcl.ps > #{$OPT_prefix}StreamFunc0-360.ps && convert #{$OPT_prefix}StreamFunc0-360.ps #{$OPT_prefix}StreamFunc0-360.png")
end

if File.exist?($OPT_prefix + 'StreamFuncDay.png') then
  puts("MESSAGE: file exists. process skipped.")
else
  system("#{script_dir}/mass_stream_func.rb V.nc V Ps.nc Ps --time_start=#{time_start} --time_end=#{time_end} --lon_start=0 --lon_end=180 --wsn=#{wsn} && dclpsrot dcl.ps > #{$OPT_prefix}StreamFunc0-180.ps && convert #{$OPT_prefix}StreamFunc0-180.ps #{$OPT_prefix}StreamFuncDay.png")
end

if File.exist?($OPT_prefix + 'StreamFuncNight.png') then
  puts("MESSAGE: file exists. process skipped.")
else
  system("#{script_dir}/mass_stream_func.rb V.nc V Ps.nc Ps --time_start=#{time_start} --time_end=#{time_end} --lon_start=180 --lon_end=360 --wsn=#{wsn} && dclpsrot dcl.ps > #{$OPT_prefix}StreamFunc180-360.ps && convert #{$OPT_prefix}StreamFunc180-360.ps #{$OPT_prefix}StreamFuncNight.png")
end
